import { IAspect, IConstruct } from "@aws-cdk/core";
export interface FSBPConfig {
    iam?: {
        fullAdmin?: boolean;
        wildcardServiceActions?: boolean;
    };
    lambda?: {
        supportedRuntimes?: boolean;
    };
}
/**
 * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html
 */
export declare class AWSFoundationalSecurityBestPracticesChecker implements IAspect {
    private Config;
    /**
     * Initialise a new Checker. All values in the configuration default to true if not provided.
     * @param config
     */
    constructor(config?: FSBPConfig);
    visit(node: IConstruct): void;
    private checkLamdaCompliance;
    /**
     * [Lambda.1] Lambda function policies should prohibit public access
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-lambda-1
     */
    private checkLambdaPublicAccess;
    private supportedLambdaRuntimes;
    /**
     * [Lambda.2] Lambda functions should use supported runtimes
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-lambda-2
     */
    private checkLambdaSupportedRuntime;
    private checkIAMPolicyCompliance;
    /**
     * [IAM.1] IAM policies should not allow full "*" administrative privileges.
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-iam-1
     */
    private checkIAMPolicyFullAdmin;
    /**
     * [IAM.21] IAM customer managed policies that you create should not allow wildcard actions for services
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-iam-21
     */
    private checkIAMPolicyServiceWildcards;
}
